# OSInfo

Operating system info 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | The operating system name | [optional] 
**vendor** | **str** | The operating system vendor | [optional] 
**version** | **str** | The operating system version | [optional] 
**release** | **str** | The operating system release | [optional] 
**architecture** | **str** | The operating system architecture | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


